import { HazelReader } from "@skeldjs/util";
import { SpawnType } from "@skeldjs/constant";
import { BaseRpcMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { Networkable, NetworkableEvents } from "../../Networkable";
import { PlayerData } from "../../PlayerData";
import { Hostable } from "../../Hostable";
import { PlayerClimbLadderEvent, PlayerEnterVentEvent, PlayerExitVentEvent } from "../../events";
import { PlayerControl } from "../PlayerControl";
export interface PlayerPhysicsData {
    ventId: number;
}
export declare type PlayerPhysicsEvents<RoomType extends Hostable = Hostable> = NetworkableEvents<RoomType> & ExtractEventTypes<[
    PlayerEnterVentEvent<RoomType>,
    PlayerExitVentEvent<RoomType>,
    PlayerClimbLadderEvent<RoomType>
]>;
/**
 * Represents a player object for handling vent entering and exiting.
 *
 * See {@link PlayerPhysicsEvents} for events to listen to.
 */
export declare class PlayerPhysics<RoomType extends Hostable = Hostable> extends Networkable<PlayerPhysicsData, PlayerPhysicsEvents, RoomType> implements PlayerPhysicsData {
    /**
     * The ID of the vent that the player is currently in.
     */
    ventId: number;
    /**
     * The player that this component belongs to.
     */
    player: PlayerData<RoomType>;
    private ladderClimbSeqId;
    constructor(room: RoomType, spawnType: SpawnType, netId: number, ownerid: number, flags: number, data?: HazelReader | PlayerPhysicsData, playerControl?: PlayerControl<RoomType>);
    get isInVent(): boolean;
    HandleRpc(rpc: BaseRpcMessage): Promise<void>;
    private _handleEnterVent;
    private _enterVent;
    private _rpcEnterVent;
    /**
     * Enter a vent on the map by its ID.
     *
     * Emits a {@link PlayerEnterVentEvent | `player.entervent`} event.
     *
     * @param ventId The ID of the vent to enter.
     * @example
     *```typescript
     * client.me.physics.enterVent(PolusVent.Office);
     * ```
     */
    enterVent(ventId: number): void;
    private _handleExitVent;
    private _exitVent;
    private _rpcExitVent;
    /**
     * Exit a vent (Does not have to be the same vent or in the same network
     * as the vent you entered).
     *
     * Emits a {@link PlayerExitVentEvent | `player.exitvent`} event.
     *
     * @param ventId The ID of the vent to exit.
     * @example
     *```typescript
     * client.me.physics.enterVent(PolusVent.Office);
     * ```
     */
    exitVent(ventId: number): void;
    private _handleClimbLadder;
    private _rpcClimbLadder;
    /**
     * Climb a ladder on the map by its ID.
     *
     * Emits a {@link PlayerClimbLadderEvent | `player.climbladder`} event.
     *
     * @param ladderid The ID of the ladder to climb.
     */
    climbLadder(ladderid: number): Promise<void>;
}
